function [T,S] = EM_kepsrp(SAT, CONTROL, STATE, TSPAN, OPTIONS)
%% Function Description

% This function provides the equations of motion for use with KepSRP.m
% Use to investigate effects of SRP on a satellite's orbit

%% Define Inputs

% Define Constants

mu_e = 398600.4415;                 % earth gravitational constant (km^3/s^2)
We = 1367;                          % average energy flux at earth (kg/s^3)
c = 2.99792458e5;                   % speed of light (km/s)
AU = 149597870.691;                 % astronomical unit (km)
d2r = pi/180;                       % conversion factor from degrees to radians

r0 = [STATE(1);STATE(2);STATE(3)];  % initial position vector (km)
v0 = [STATE(4); STATE(5);STATE(6)]; % initial velocity vector (km/s)
s0 = [r0;v0];                       % initial state vector
A = SAT(1);                         % area of solar surface(km^2)
m = SAT(2);                         % mass of satellite (kg)
jd0 = STATE(7);                     % initial julian date

[T,S] = ode45(@eq,TSPAN,s0,OPTIONS);    % ode45 integration scheme

%% Equations of Motion

    function ds = eq(time,input)
        
        r = input(1:3);                                                         % position vector
        v = input(4:6);                                                         % velocity vector
        jd = jd0 + time/86400;                                                	% julian date
        Tc = (jd-2451545)/36525;                                              	% number of julian centuries past J2000.0
        ep_e = (23.439291-0.0130042*Tc-(1.64e-7)*(Tc.^2)+(5.04e-7)*Tc.^3)*d2r;	% obliquity of the ecliptic
        
        % Position of Sun
        LMS = (280.460 + 36000.771*Tc)*d2r;
        MS = (357.527723+35999.05034*Tc)*d2r;
        Lec_s = LMS + (1.914666471*d2r)*sin(MS)+(0.019994643*d2r)*sin(2*MS);
        rs = 1.000140612-0.016708617*cos(MS)-0.000139589*cos(2*MS);
        rsx = rs.*cos(Lec_s);
        rsy = rs.*cos(ep_e).*sin(Lec_s);
        rsz = rs.*sin(ep_e).*sin(Lec_s);
        r_s = AU*[rsx;rsy;rsz];
        e_s = r_s/norm(r_s);
       
        % Determination of Sail Surface Normal Direction
        if CONTROL == 0
            n = [0;0;0];
        elseif CONTROL == 1
            n = e_s;
        elseif dot(v,r_s)<0
            n = -v/norm(v);
        else
            n = [0;0;0];
        end
        
        % SRP Acceleration
        P = (We/c)*((AU/norm(r_s-r))^2);    % Position based Solar Radiation Pressure
        cth = n'*e_s;                       % Angle between Sun position vector and satellite surface normal
        acc_srp = -2*P*(A/m)*cth*cth*n;
        
        % Earth Acceleration
        acc_earth = (-mu_e/norm(r)^3)*r;
        
        % Total Acceleration
        acc_t = acc_earth + acc_srp;
        ds = [v;acc_t];
        
    end

end


