clc
clear all

%% Define Constants and Initial Conditions

mu_e = 398600.4415;     % Earth gravitational constant (km^3/s^2)
Re = 6378.137;          % Radius of Earth (km)
tsol = 86400;           % Solar Day (sec)
r_GEO = 42164;          % Radius of GEO Belt (km)
tf = 1*365;             % Simulation Length (days)

% Date
year = 2015;
month = 10;
day = 15;
hour = 0;
minute = 0;
second = 0;

% Characterize Satellite
A = 1208e-6;            % Sail Surface Area (km^2)
m = 50;                 % Satellite Mass(kg)

% Initial Position Vector Elements
x = r_GEO;
y = 0;
z = 0;

% Initial Velocity Vector Elements
vx = 0;
vy = sqrt(mu_e/x);
vz = 0;

CONTROL = 2; 
% Set to 0 to turn off SRP
% Set to 1 to face Sun 
% Set to 2 to raise SMA
%% Evaluate

jd0 = juliandate([year;month;day;hour;minute;second]);
SAT = [A m];
STATE = [x y z vx vy vz jd0];
TSPAN = [0 tf*86400];
OPTIONS = odeset('RelTol',1e-6,'AbsTol',1e-6,'NormControl','on');%,'Maxstep',tf/20000);
[T,S] = EM_kepsrp(SAT, CONTROL, STATE, TSPAN, OPTIONS);

%% Investigate

X = S(:,1)';                    % resulting x positions (km)
Y = S(:,2)';                	% resulting y positions (km)
Z = S(:,3)';                    % resulting z positions (km)
VX = S(:,4)';                   % resulting x velocities (km/s)
VY = S(:,5)';               	% resulting y velocities (km/s)
VZ = S(:,6)';               	% resulting z velocities (km/s)
r = [X;Y;Z];                    % resulting position vectors (km)
R = sqrt(X.^2+Y.^2+Z.^2);       % resulting position magnitudes (km)
v = [VX;VY;VZ];                 % resulting velocity vectors (km/s)
V = sqrt(VX.^2+VY.^2+VZ.^2);	% resulting velocity magnitudes (km/s)

% Retrieve Orbital Elements
[p, a, e, inc, W, w, nu, w_true, u, lda] = rv2coe(r,v);

% Create GEO Belt
th = 0:360;
xx = r_GEO*cosd(th);
yy = r_GEO*sind(th);
zz = zeros(1,361);


%% Figures

% Create GEO Belt
th = 0:360;
xx = r_GEO*cosd(th);
yy = r_GEO*sind(th);
zz = zeros(1,361);

figure, plot3(X,Y,Z,X(1),Y(1),Z(1),'om',X(end),Y(end),Z(end),'xm',xx,yy,zz,'r'), axis equal, title('Satellite Orbit')
xlabel('X Position (km)'), ylabel('Y Position (km)'), zlabel('Z Position (km)')
load('topo.mat', 'topo', 'topomap1'); [Xs,Ys,Zs] = sphere; 
props.FaceColor= 'texture'; props.EdgeColor = 'none'; 
props.FaceLighting = 'phong'; props.CData = topo; 
s=surface(6378*Xs,6378*Ys,6378*Zs,props);

figure
subplot(3,2,1), plot(T/tsol,R,T/tsol,r_GEO*ones(1,length(T)),'r'), title('Position Magnitude vs Time'), grid on
xlabel('Time (days)'), xlim([0 T(end)/tsol]), ylabel('Position Magnitude (km)'),legend('Position Magnitude','GEO Belt','Location','northwest')
subplot(3,2,2), plot(T/tsol,a),title('Semi-Major Axis vs Time'), grid on
xlabel('Time (days)'), xlim([0 T(end)/tsol]), ylabel('Semi-Major Axis (km)')
subplot(3,2,3),  plot(T/tsol,e), title ('Eccentricity vs Time'), grid on
xlabel('Time (days)'), xlim([0 T(end)/tsol]),ylabel('Eccentricity')
subplot(3,2,4),  plot(T/tsol,inc), title ('Inclination vs Time'), grid on
xlabel('Time (days)'), xlim([0 T(end)/tsol]),ylabel('Eccentricity')
subplot(3,2,5),  plot(T/tsol,W), title ('RAAN vs Time'), grid on
xlabel('Time (days)'), xlim([0 T(end)/tsol]),ylabel('Eccentricity')
subplot(3,2,6),  plot(T/tsol,w), title ('Argument of Perigee vs Time'), grid on
xlabel('Time (days)'), xlim([0 T(end)/tsol]),ylabel('Eccentricity')
